Alligators: Untabeled alligator food choice data

AlligatorsR Documentation

Untabeled alligator food choice data

Description

Untabeled alligator food choice data

Usage

data(Alligators)

Format

A data frame with 219 rows corresponding to captured alligator and 5 variables:

* 'foodchoice': primary food type, in volume, found in an alligator’s stomach, with levels 'fish', 'invertebrate','reptile', 'bird', 'other' * 'lake': lake of capture with levels 'Hancock', 'Oklawaha', 'Trafford', 'George'. * 'sex': sex of the alligator with levels 'Male' and 'Female' * 'size': size of the alligator with levels '<=2.3' meters long and '>2.3' meters long * 'freq': number of alligators for each foodchoice, lake, gender and size combination

The alligators data set is analyzed in Agresti (2002, Subsection 7.1.2). These data are an untabeled version.

References

Agresti A (2002). *Categorical Data Analysis*. Wiley Series in Probability and Statistics. Wiley.


divoRce documentation built on April 28, 2026, 3:01 a.m.

Related to Alligators in divoRce...