b_Xstar: Function to calculate the negative structure vector matrix X*...

View source: R/b_Xstar.R

b_XstarR Documentation

Function to calculate the negative structure vector matrix X* for binary outcomes.

Description

Function to calculate the negative structure vector matrix X* for binary outcomes.

Usage

b_Xstar(y, X, label = TRUE, rational = FALSE)

Arguments

y

a binary outcome variable. Works best if it is a factor but can also be numeric, boolean or character.

X

a design matrix, e.g. generated via a call to model.matrix or via the function make_yx. This means we expect that X already contains the desired contrasts for factors (e.g., dummies) and any other expanded columns (e.g., for polynomials).

label

should the structure vector matrix have row and column labels?

rational

should the structure vectors been given in rational format?

Details

If X is given as the standard R object for design matrices (i.e., a numeric matrix), they are returned the same way unless rational=TRUE; then it is returned as a character matrix of rational numbers. If X is given in rational format, it is also returned as rational format even if rational is set to FALSE.

Value

a matrix of negative structure vectors with or without labels.


divoRce documentation built on April 28, 2026, 3:01 a.m.

Related to b_Xstar in divoRce...