| bcl_Xstar | R Documentation |
Function to calculate the negative structure vector matrix X* for baseline-category outcomes.
bcl_Xstar(y, X, label = TRUE, rational = FALSE)
y |
a nominal or binary outcome variable. Works best if it is a factor but can also be numeric, boolean or character. |
X |
a design matrix, e.g. generated via a call to |
label |
should the structure vector matrix have row and column labels? |
rational |
should the structure vectors been given in rational format? |
If X is given as the standard R object for design matrices (i.e., a numeric matrix), they are returned the same way unless rational=TRUE; then it is returned as a character matrix of rational numbers. If X is given in rational format, it is also returned as rational format even if rational is set to FALSE. This returned matrix is like -struc_vec(y,X).
a matrix of negative structure vectors with or without labels.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.