| nsduh2019 | R Documentation |
These data are from Nahhas (2024) to illustrate quasi-complete separation in his book Introduction to Regression Methods for Public Health Using R.
data(nsduh2019)
A 843 x 4 data frame:
A binary factor of heroin consumption in a person's lifetime ('No' and 'Yes').
Age at first use of alcohol.
Current age category of the person.
Sex of the person "Male" or ""Female".
Nahhas R. (2024). Introduction to Regression Methods for Public Health Using R. Chapman & Hall.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.