| reccone_osm | R Documentation |
This function returns the structure vectors that are not linearities (comprising the recession cone), the recession cone dimension and the row index of the structure vectors that are not linearities (mnaking up the recession cone).
reccone_osm(y, X, rational = FALSE)
y |
the outcome variable. Works best if it is a factor or ordered factor but can also be numeric, boolean or character. |
X |
a design matrix, e.g. generated via a call to 'model.matrix'. This means we expect that X already contains the desired contrasts for factors (e.g., dummies) and any other expanded columns (e.g., for polynomials). |
rational |
boolean flag whether rational arithmetic should be used. Default is FALSE. |
a list with 'cone' being the recession cone, 'reccdim' being the dimensions of the recession cone, and 'index' the row index of the structure vectors that are not linearities. Note that in case of 'X' not having full column rank, the 'reccdim' value is the dimension of the recession cone due to separation plus the number of columns that are linear dependent.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.