| titanic3 | R Documentation |
This data set contains the subset of people in the Titanic data sets that were aged 3. It shows various separation types depending on the model fitted.
data(titanic3)
A 6 x 12 data frame:
ID of the passenger
Survived? (1=yes, 0=no)
Passenger Class (1=upper, 2=middle, 3=lower).
Name.
Sex of the person.
Age of the person. All are 3 yrs.
Number of siblings or spouses on board the ship.
Number of parents or children on board the ship.
Ticket number
.
Passenger fare.
Cabin number.
Port of embarkation (C=Cherbourg, Q=Queenstown, S=Southampton).
Will Cukierski. Titanic - Machine Learning from Disaster. https://kaggle.com/competitions/titanic, 2012. Kaggle.
with(titanic3,ftable(Survived~Sex+Pclass))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.