| Alligators | R Documentation |
Untabeled alligator food choice data
data(Alligators)
A data frame with 219 rows corresponding to captured alligator and 5 variables:
* 'foodchoice': primary food type, in volume, found in an alligator’s stomach, with levels 'fish', 'invertebrate','reptile', 'bird', 'other' * 'lake': lake of capture with levels 'Hancock', 'Oklawaha', 'Trafford', 'George'. * 'sex': sex of the alligator with levels 'Male' and 'Female' * 'size': size of the alligator with levels '<=2.3' meters long and '>2.3' meters long * 'freq': number of alligators for each foodchoice, lake, gender and size combination
The alligators data set is analyzed in Agresti (2002, Subsection 7.1.2). These data are an untabeled version.
Agresti A (2002). *Categorical Data Analysis*. Wiley Series in Probability and Statistics. Wiley.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.