| checkovl | R Documentation |
This function checks for overlap by calling the appropriate low-level functions.
checkovl(
y,
X,
S,
rational = FALSE,
model = c("bcl", "b", "cl", "acl", "sl", "osm"),
backend = c("rcdd", "ROI"),
solver = NULL
)
y |
outcome vector |
X |
design matrix |
S |
structure vector matrix |
rational |
should rational arithmetic be used. |
model |
what model class is intended to be fitted? Can be any of "b" for binary, "bcl" for baseline-category link, "cl" for cumulative link, "acl" for adjacent-category link. "sl" for sequential link, "osm" for ordered stereotype model. If missing or NULL it defaults to cumulative link for ordinal y and baseline-category for everything else. |
backend |
which backend to use for the linear program. Can be "rcdd" (default and only option for rational=TRUE) or "ROI". |
solver |
the solver to be used in the backend. Defaults to "DualSimplex" for "rcdd" and the first LP solver returned by 'ROI_applicable_solver()' for "ROI". |
The function uses either a response vector y and a design matrix X or a structure vector matrix S. If S is given, y and X and model are ignored.
a Boolean; either 'TRUE' if there is overlap or 'FALSE' if not.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.