| seprows_bcl | R Documentation |
This function checks which rows in X/Xstar are responsible for separation on any category. The observations need not separate the same categories.
seprows_bcl(y, X, rational = FALSE)
detect_seprows_bcl(y, X, rational = FALSE)
y |
the ordinal outcome variable. Works best if it is an ordered factor but can also be numeric, boolean or character. In the latter case we corece to ordered factor and interpret the ordering as alphanumerically increasing (just as as.ordered is doing). |
X |
a design matrix, e.g. generated via a call to 'model.matrix'. This means we expect that X already contains the desired contrasts for factors (e.g., dummies) and any other expanded columns (e.g., for polynomials). |
rational |
should rational arithmetic be used? |
a list with elements:
offrows the submatrix of the matrix (X,y) with the rows responsible for separation on any category.
index the index of the rows responsible for separation.
data(qcsepdatm)
y<-qcsepdatm$y
X<-qcsepdatm[,2:ncol(qcsepdatm)]
seprows_bcl(y,X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.