| struc_vec | R Documentation |
Function to calculate the structure vector matrix X* for categorical outcomes.
struc_vec(y, X, label = TRUE, rational = FALSE)
y |
an outcome variable. Should be a factor else we order increasingly in an alpha-numeric fashion. |
X |
a design matrix, e.g. generated via a call to |
label |
should the structure vector matrix have row and column labels? |
rational |
should the matrices be returned in rational format? |
If X is given as the standard R object for design matrices (i.e., a numeric matrix), the structure vector matrix is returned the same way unless rational=TRUE; then it is returned as a character matrix of rational numbers. If X is given in rational format, it is also returned as rational format even if rational is set to FALSE. This returned matrix is like -nomin_Xstar(y,X).
a matrix of structure vectors with or without labels
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.